@@ -14,7 +14,7 @@
 #' @export
 
 imf_ids <- function(return_raw = FALSE, times = 3) {
-    URL <- 'http://dataservices.imf.org/REST/SDMX_JSON.svc/Dataflow?format=sdmx-json'
+    URL <- 'http://dataservices.imf.org/REST/SDMX_JSON.svc/Dataflow'
     raw_dl <- download_parse(URL)
 
     if (!isTRUE(return_raw)) {
